summaryrefslogtreecommitdiffhomepage
path: root/dev/ZKA/KernelKit/FileMgr.hxx
diff options
context:
space:
mode:
authorAmlal <amlal@el-mahrouss-logic.com>2024-09-08 08:18:37 +0200
committerAmlal <amlal@el-mahrouss-logic.com>2024-09-08 08:18:37 +0200
commitdf8a42aa1266d953a9ee473afe9f6349bd1837c7 (patch)
treecad53c222ca90ee98ac82ee2d630a4ff0b0c3ee3 /dev/ZKA/KernelKit/FileMgr.hxx
parent884ea5c2d43b6c8d4c2bb4fc33c11dc2313eeca2 (diff)
[dev/FeatureAdd] Add mm_new_class, as C++ new doesn't initialize class directly.
[dev/FeatureFix] CR2 set to invalid address due to stack corruption, fixing that. Signed-off-by: Amlal <amlal@el-mahrouss-logic.com>
Diffstat (limited to 'dev/ZKA/KernelKit/FileMgr.hxx')
-rw-r--r--dev/ZKA/KernelKit/FileMgr.hxx20
1 files changed, 10 insertions, 10 deletions
diff --git a/dev/ZKA/KernelKit/FileMgr.hxx b/dev/ZKA/KernelKit/FileMgr.hxx
index 86eade6a..5b2b8fa8 100644
--- a/dev/ZKA/KernelKit/FileMgr.hxx
+++ b/dev/ZKA/KernelKit/FileMgr.hxx
@@ -74,28 +74,28 @@ namespace Kernel
@brief Filesystem Mgr Interface class
@brief Used to provide common I/O for a specific filesystem.
*/
- class FilesystemMgrInterface
+ class IFilesystemMgr
{
public:
- explicit FilesystemMgrInterface() = default;
- virtual ~FilesystemMgrInterface() = default;
+ explicit IFilesystemMgr() = default;
+ virtual ~IFilesystemMgr() = default;
public:
- ZKA_COPY_DEFAULT(FilesystemMgrInterface);
+ ZKA_COPY_DEFAULT(IFilesystemMgr);
public:
/// @brief Mounts a new filesystem into an active state.
/// @param interface the filesystem interface
/// @return
- static bool Mount(FilesystemMgrInterface* interface);
+ static bool Mount(IFilesystemMgr* interface);
/// @brief Unmounts the active filesystem
/// @return
- static FilesystemMgrInterface* Unmount();
+ static IFilesystemMgr* Unmount();
/// @brief Getter, gets the active filesystem.
/// @return
- static FilesystemMgrInterface* GetMounted();
+ static IFilesystemMgr* GetMounted();
public:
virtual NodePtr Create(_Input const Char* path) = 0;
@@ -137,10 +137,10 @@ namespace Kernel
#ifdef __FSKIT_USE_NEFS__
/**
* @brief Based of FilesystemMgrInterface, takes care of managing NeFS
* disks.
*/
- class NewFilesystemMgr final : public FilesystemMgrInterface
+ class NewFilesystemMgr final : public IFilesystemMgr
{
public:
explicit NewFilesystemMgr();
@@ -192,7 +192,7 @@ namespace Kernel
* @tparam FSClass Filesystem contract who takes care of it.
*/
template <typename Encoding = Char,
- typename FSClass = FilesystemMgrInterface>
+ typename FSClass = IFilesystemMgr>
class FileStream final
{
public:
@@ -137,10 +137,10 @@ namespace Kernel
#ifdef __FSKIT_USE_NEFS__
/**
- * @brief Based of FilesystemMgrInterface, takes care of managing NeFS
+ * @brief Based of IFilesystemMgr, takes care of managing NeFS
* disks.
*/